@@ -1,4 +1,3 @@
-from gettext import gettext as _
 from le_utils.constants import file_formats
 
 """ File Type Constants """
@@ -8,8 +7,10 @@ AUDIO = "audio"
 DOCUMENT = "document"
 EPUB = "epub"
 HTML5 = "html5"
+H5P = "h5p"
 THUMBNAIL = "thumbnail"
 SUBTITLES = "subtitles"
+SLIDESHOW_IMAGE = "slideshow_image"
 
 
 """ File Format (extension) to File Type Mapping """
@@ -29,11 +30,12 @@ MAPPING = {
     #
     # formats HTMLZipFile
     file_formats.HTML5: HTML5,
+    # formats H5PFile
+    file_formats.H5P: H5P,
     #
     # formats VideoFile
     file_formats.MP4: VIDEO,
     #
     # formats SubtitleFile
     file_formats.VTT: SUBTITLES,
-    file_formats.SRT: SUBTITLES,
 }
